@@ -1,8 +1,10 @@
 # -*- coding: utf-8 -*-
 import os.path
 import time
-from typing import Any, Dict, List
+from datetime import datetime
+from typing import Any, Dict, List, Tuple
 
+import dateparser
 import httplib2
 from chaoslib.discovery.discover import (
     discover_actions,
@@ -33,8 +35,9 @@ __all__ = [
     "load_credentials",
     "to_dict",
     "context_from_parent_path",
+    "parse_interval",
 ]
-__version__ = "0.5.0"
+__version__ = "0.8.0"
 
 
 def get_service(
@@ -90,7 +93,9 @@ def context_from_parent_path(parent: str) -> GCPContext:
     )
 
 
-def wait_on_operation(operation_service: Any, **kwargs: Dict) -> Dict[str, Any]:
+def wait_on_operation(
+    operation_service: Any, frequency: int = 1, **kwargs: Dict
+) -> Dict[str, Any]:
     """
     Wait until the given operation is completed and return the result.
     """
@@ -106,7 +111,7 @@ def wait_on_operation(operation_service: Any, **kwargs: Dict) -> Dict[str, Any]:
         if result["status"] == "DONE":
             return result
 
-        time.sleep(1)
+        time.sleep(frequency)
 
 
 def load_credentials(secrets: Secrets = None):
@@ -159,6 +164,10 @@ def load_credentials(secrets: Secrets = None):
     service_account_file = secrets.get("service_account_file")
     service_account_info = secrets.get("service_account_info")
 
+    google_app_creds = os.getenv("GOOGLE_APPLICATION_CREDENTIALS")
+    if google_app_creds:
+        service_account_file = google_app_creds
+
     credentials = None
     if service_account_file:
         service_account_file = os.path.expanduser(service_account_file)
@@ -248,6 +257,29 @@ def to_dict(response: Any) -> dict:
     return response.__class__.to_dict(response)
 
 
+def parse_interval(
+    end_time: str = "now", window: str = "1h"
+) -> Tuple[datetime, datetime]:
+    end_time = dateparser.parse(
+        end_time, settings={"TIMEZONE": "UTC", "RETURN_AS_TIMEZONE_AWARE": True}
+    )
+    if not end_time:
+        raise ActivityFailed("unparsable end time value")
+
+    start_time = dateparser.parse(
+        window,
+        settings={
+            "TIMEZONE": "UTC",
+            "RELATIVE_BASE": end_time,
+            "RETURN_AS_TIMEZONE_AWARE": True,
+        },
+    )
+    if not start_time:
+        raise ActivityFailed("unparsable window value")
+
+    return (start_time, end_time)
+
+
 ###############################################################################
 # Private functions
 ###############################################################################
@@ -265,4 +297,6 @@ def load_exported_activities() -> List[DiscoveredActivities]:
     activities.extend(discover_probes("chaosgcp.cloudbuild.probes"))
     activities.extend(discover_actions("chaosgcp.cloudrun.actions"))
     activities.extend(discover_probes("chaosgcp.cloudrun.probes"))
+    activities.extend(discover_probes("chaosgcp.monitoring.probes"))
+    activities.extend(discover_probes("chaosgcp.cloudlogging.probes"))
     return activities
